/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_FLANGR.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_FLANGR *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_FLANGR_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_FLANGR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_FLANGR(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_FLANGR_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_FLANGR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_FLANGR(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_FLANGR_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_FLANGR();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_FLANGR::Heavy_WSTD_FLANGR(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_R25WMDtl);
  numBytes += sPhasor_k_init(&sPhasor_EZZuEyEr, 2.0f, sampleRate);
  numBytes += sLine_init(&sLine_nf7zY553);
  numBytes += sRPole_init(&sRPole_X5mvBjap);
  numBytes += sRPole_init(&sRPole_RZBUGl7o);
  numBytes += sTabhead_init(&sTabhead_rnJ21DA8, &hTable_M7LtidNy);
  numBytes += sTabread_init(&sTabread_NTDDH6VF, &hTable_M7LtidNy, false);
  numBytes += sTabread_init(&sTabread_PNwHZz5J, &hTable_M7LtidNy, false);
  numBytes += sLine_init(&sLine_TbYIJyE8);
  numBytes += sTabhead_init(&sTabhead_NDUXXQMv, &hTable_LlgIMSkF);
  numBytes += sTabread_init(&sTabread_DS4vaCZM, &hTable_LlgIMSkF, false);
  numBytes += sTabread_init(&sTabread_YYfSz6CP, &hTable_LlgIMSkF, false);
  numBytes += sLine_init(&sLine_wuT9gamT);
  numBytes += sTabwrite_init(&sTabwrite_1ixSPqql, &hTable_LlgIMSkF);
  numBytes += sTabwrite_init(&sTabwrite_eamEmQVd, &hTable_M7LtidNy);
  numBytes += cVar_init_f(&cVar_HwTPrDxZ, 0.0f);
  numBytes += cVar_init_f(&cVar_i1zEDy6b, 0.0f);
  numBytes += cVar_init_f(&cVar_Z7NN4Ukh, 0.0f);
  numBytes += cVar_init_f(&cVar_XNCXEE98, 0.0f);
  numBytes += cVar_init_s(&cVar_E4Uk2yo4, "del-1010-flanger-l");
  numBytes += sVarf_init(&sVarf_aX55ZHh0, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_XkVwlHNR, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_uHMQ7Bnh, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_ADCgry4n, "del-1010-flanger-r");
  numBytes += sVarf_init(&sVarf_gnekxkyT, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_j80Hudrf, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_zdqTmKtj, 0.0f, 0.0f, false);
  numBytes += cDelay_init(this, &cDelay_ktd1YUUy, 0.0f);
  numBytes += cDelay_init(this, &cDelay_qs6htUFW, 0.0f);
  numBytes += hTable_init(&hTable_LlgIMSkF, 256);
  numBytes += cDelay_init(this, &cDelay_d5x1DpXx, 0.0f);
  numBytes += cDelay_init(this, &cDelay_VQffMIKK, 0.0f);
  numBytes += hTable_init(&hTable_M7LtidNy, 256);
  numBytes += cVar_init_f(&cVar_H4KD5A0V, 14.0f);
  numBytes += cBinop_init(&cBinop_HWvOm9Ny, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_zLRZcbuI, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_hXvIjBtS, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_yWisupRi, 14.0f);
  numBytes += cBinop_init(&cBinop_hI6pTwi1, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_Uyk69t9V, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_v5KyDIX7, 0.0f, 0.0f, false);
  numBytes += cBinop_init(&cBinop_opCCArKP, 0.0f); // __mul
  numBytes += cSlice_init(&cSlice_CxtlHDBG, 1, -1);
  numBytes += cVar_init_f(&cVar_YeH0PLL1, 0.2f);
  numBytes += cSlice_init(&cSlice_C1keHI8g, 1, -1);
  numBytes += cVar_init_f(&cVar_iZGPSRnd, 0.0f);
  numBytes += cSlice_init(&cSlice_gfrUcuP0, 1, -1);
  numBytes += cVar_init_f(&cVar_MWCMmjE4, 2.0f);
  numBytes += cSlice_init(&cSlice_NJhBiftw, 1, -1);
  numBytes += cVar_init_f(&cVar_ZxTH6Pyt, 0.5f);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_FLANGR::~Heavy_WSTD_FLANGR() {
  hTable_free(&hTable_LlgIMSkF);
  hTable_free(&hTable_M7LtidNy);
}

HvTable *Heavy_WSTD_FLANGR::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0x297C7484: return &hTable_LlgIMSkF; // del-1010-flanger-r
    case 0x7DBB345F: return &hTable_M7LtidNy; // del-1010-flanger-l
    default: return nullptr;
  }
}

void Heavy_WSTD_FLANGR::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0x57157946: { // Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_PshM2mDu_sendMessage);
      break;
    }
    case 0x20BB009B: { // Intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4tIz208N_sendMessage);
      break;
    }
    case 0x97D46AC6: { // Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_IRYbXjDZ_sendMessage);
      break;
    }
    case 0x9A248230: { // Speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_T6wb7rrT_sendMessage);
      break;
    }
    case 0xD6AF3228: { // 1010-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_iTyHNayB_sendMessage);
      break;
    }
    case 0x68077D82: { // 1010-intensity
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_xa80hR6C_sendMessage);
      break;
    }
    case 0x36F9AB4: { // 1010-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_2HIYiN9z_sendMessage);
      break;
    }
    case 0xF709FF0E: { // 1010-speed
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_lMUW4j4C_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_MQAcVnfn_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_FLANGR::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "Feedback";
        info->hash = 0x57157946;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -100.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "Intensity";
        info->hash = 0x20BB009B;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 2: {
        info->name = "Mix";
        info->hash = 0x97D46AC6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 3: {
        info->name = "Speed";
        info->hash = 0x9A248230;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 20.0f;
        info->defaultVal = 2.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 4;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_FLANGR::cVar_HwTPrDxZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Dqwzx8mq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cVar_i1zEDy6b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pRL567Zm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cVar_Z7NN4Ukh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_RV229yGR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cVar_XNCXEE98_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WeGTBPUJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cBinop_b2KXg1rx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_dgqPQoyS_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_dgqPQoyS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sPhasor_k_onMessage(_c, &Context(_c)->sPhasor_EZZuEyEr, 0, m);
}

void Heavy_WSTD_FLANGR::cMsg_qhKx5iIA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_M67JPdRz_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_M67JPdRz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_iR2ZjAlF_sendMessage);
}

void Heavy_WSTD_FLANGR::cVar_E4Uk2yo4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_CPdPVjdG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSystem_ljxv6Y1E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_uPJjFuh5_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_aX55ZHh0, m);
}

void Heavy_WSTD_FLANGR::cBinop_iR2ZjAlF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_XkVwlHNR, m);
}

void Heavy_WSTD_FLANGR::cMsg_CPdPVjdG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ljxv6Y1E_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_uPJjFuh5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_uHMQ7Bnh, m);
}

void Heavy_WSTD_FLANGR::cMsg_EDLkdWcw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_uDnM8CHs_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_uDnM8CHs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_d1ZhB3t0_sendMessage);
}

void Heavy_WSTD_FLANGR::cVar_ADCgry4n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_buEiLFiM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSystem_7O5qmszt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_xICAASKZ_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_gnekxkyT, m);
}

void Heavy_WSTD_FLANGR::cBinop_d1ZhB3t0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_j80Hudrf, m);
}

void Heavy_WSTD_FLANGR::cMsg_buEiLFiM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_7O5qmszt_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_xICAASKZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_zdqTmKtj, m);
}

void Heavy_WSTD_FLANGR::cBinop_YAoLXO1T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_z106eGAS_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_z106eGAS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_NNkgkPNg_sendMessage);
}

void Heavy_WSTD_FLANGR::cUnop_GKqS375D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LSGy01Ua_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cUnop_pkK4AXOD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_E7QFQjoH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cBinop_NNkgkPNg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_BOkGGd5n_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_BOkGGd5n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Cxcvu6wl_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gCXbP3zR_sendMessage);
}

void Heavy_WSTD_FLANGR::cCast_gCXbP3zR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IFhlU4ZJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cCast_Cxcvu6wl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_4LqImXNh_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_4LqImXNh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_kM7TPWMU_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_IFhlU4ZJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_GVpRyKH4_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_GVpRyKH4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_frrC4wpv_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_kM7TPWMU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_GKqS375D_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_frrC4wpv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_pkK4AXOD_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_FDuflrnr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_zmLApObq_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_zmLApObq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rUmrdgS4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cMsg_JiQUqS8d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_jflvpGvp_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_jflvpGvp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_2VcpjHvm_sendMessage);
}

void Heavy_WSTD_FLANGR::cDelay_ktd1YUUy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ktd1YUUy, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_qs6htUFW, 0, m, &cDelay_qs6htUFW_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ktd1YUUy, 0, m, &cDelay_ktd1YUUy_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_1ixSPqql, 1, m, NULL);
}

void Heavy_WSTD_FLANGR::cDelay_qs6htUFW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_qs6htUFW, m);
  cMsg_P0F5h3UX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSwitchcase_0n5r20z7_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_i6NqQLm9_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cBinop_QU9jwFwC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pCy1dkFL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::hTable_LlgIMSkF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xMMSpn4Q_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_ktd1YUUy, 2, m, &cDelay_ktd1YUUy_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cZXzg7kn_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_pCy1dkFL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_LlgIMSkF, 0, m, &hTable_LlgIMSkF_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_2VcpjHvm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_QU9jwFwC_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_P0F5h3UX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_LlgIMSkF, 0, m, &hTable_LlgIMSkF_sendMessage);
}

void Heavy_WSTD_FLANGR::cCast_cZXzg7kn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ktd1YUUy, 0, m, &cDelay_ktd1YUUy_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_xMMSpn4Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_qs6htUFW, 2, m, &cDelay_qs6htUFW_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_i6NqQLm9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_1ixSPqql, 1, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_QQ6ZAyzv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_BWgThfTN_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_BWgThfTN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_rRwF8VO7_sendMessage);
}

void Heavy_WSTD_FLANGR::cDelay_d5x1DpXx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_d5x1DpXx, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_VQffMIKK, 0, m, &cDelay_VQffMIKK_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_d5x1DpXx, 0, m, &cDelay_d5x1DpXx_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_eamEmQVd, 1, m, NULL);
}

void Heavy_WSTD_FLANGR::cDelay_VQffMIKK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_VQffMIKK, m);
  cMsg_6DfE5Xzh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSwitchcase_UAbazszT_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_kvSJC1S9_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cBinop_UpbptDXG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aLoaeQ13_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::hTable_M7LtidNy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ua7bQKLw_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_d5x1DpXx, 2, m, &cDelay_d5x1DpXx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MPlEYjcA_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_aLoaeQ13_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_M7LtidNy, 0, m, &hTable_M7LtidNy_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_rRwF8VO7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 20.0f, 0, m, &cBinop_UpbptDXG_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_6DfE5Xzh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_M7LtidNy, 0, m, &hTable_M7LtidNy_sendMessage);
}

void Heavy_WSTD_FLANGR::cCast_MPlEYjcA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_d5x1DpXx, 0, m, &cDelay_d5x1DpXx_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_ua7bQKLw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_VQffMIKK, 2, m, &cDelay_VQffMIKK_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_kvSJC1S9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_eamEmQVd, 1, m, NULL);
}

void Heavy_WSTD_FLANGR::cVar_H4KD5A0V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HWvOm9Ny, HV_BINOP_MULTIPLY, 0, m, &cBinop_HWvOm9Ny_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_6rvaHEbv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_n9sLrFLw_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_n9sLrFLw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Aykgt5no_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cBinop_HWvOm9Ny_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_c2VmB4pJ_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_TdyozPUV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_HWvOm9Ny, HV_BINOP_MULTIPLY, 1, m, &cBinop_HWvOm9Ny_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_Aykgt5no_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_TdyozPUV_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_c2VmB4pJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_8kHVMDen_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_8kHVMDen_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_wstOkoPJ_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_hXvIjBtS, m);
}

void Heavy_WSTD_FLANGR::cBinop_wstOkoPJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_zLRZcbuI, m);
}

void Heavy_WSTD_FLANGR::cVar_yWisupRi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hI6pTwi1, HV_BINOP_MULTIPLY, 0, m, &cBinop_hI6pTwi1_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_1VKgQpfU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_nJdkwEAv_sendMessage);
}

void Heavy_WSTD_FLANGR::cSystem_nJdkwEAv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_g5XVORdI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cBinop_hI6pTwi1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_4K0wdpK6_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_RSFX4cBx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hI6pTwi1, HV_BINOP_MULTIPLY, 1, m, &cBinop_hI6pTwi1_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_g5XVORdI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_RSFX4cBx_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_4K0wdpK6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_Hl4sFdD5_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_Hl4sFdD5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_wYSmyn3K_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_v5KyDIX7, m);
}

void Heavy_WSTD_FLANGR::cBinop_wYSmyn3K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Uyk69t9V, m);
}

void Heavy_WSTD_FLANGR::cMsg_rUmrdgS4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nf7zY553, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cUnop_p1YbjCbt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.01f, 0, m, &cBinop_2p80xbFM_sendMessage);
}

void Heavy_WSTD_FLANGR::cCast_v5MbXFPF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_F2Bq0ygB_sendMessage);
}

void Heavy_WSTD_FLANGR::cCast_JqNwI0t1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_p1YbjCbt_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_gj3wttXq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_Kh6Mt6Bq_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_Kh6Mt6Bq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_opCCArKP, HV_BINOP_MULTIPLY, 1, m, &cBinop_opCCArKP_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_F2Bq0ygB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_gj3wttXq_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_opCCArKP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cDZUsf6S_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cBinop_2p80xbFM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_opCCArKP, HV_BINOP_MULTIPLY, 0, m, &cBinop_opCCArKP_sendMessage);
}

void Heavy_WSTD_FLANGR::cMsg_cDZUsf6S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_wuT9gamT, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cBinop_QfOk2mf9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, -1.0f, 0, m, &cBinop_tT2aBm9c_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_tT2aBm9c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_v5MbXFPF_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JqNwI0t1_sendMessage);
}

void Heavy_WSTD_FLANGR::cSwitchcase_PTQYycrb_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3D836879: { // "intensity"
      cSlice_onMessage(_c, &Context(_c)->cSlice_CxtlHDBG, 0, m, &cSlice_CxtlHDBG_sendMessage);
      break;
    }
    default: {
      cSwitchcase_0wyqN356_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cSlice_CxtlHDBG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_GeJv0Zbs_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_GeJv0Zbs_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FLANGR::cVar_YeH0PLL1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_GeJv0Zbs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSend_GeJv0Zbs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_xa80hR6C_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSwitchcase_0wyqN356_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_C1keHI8g, 0, m, &cSlice_C1keHI8g_sendMessage);
      break;
    }
    default: {
      cSwitchcase_1rpLPxbT_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cSlice_C1keHI8g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_rb75OlzK_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_rb75OlzK_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FLANGR::cVar_iZGPSRnd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_rb75OlzK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSend_rb75OlzK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_iTyHNayB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSwitchcase_1rpLPxbT_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x29E4A0EF: { // "speed"
      cSlice_onMessage(_c, &Context(_c)->cSlice_gfrUcuP0, 0, m, &cSlice_gfrUcuP0_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Bwv3DNnF_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cSlice_gfrUcuP0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_covEy1Yb_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_covEy1Yb_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FLANGR::cVar_MWCMmjE4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_covEy1Yb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSend_covEy1Yb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_lMUW4j4C_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSwitchcase_Bwv3DNnF_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_NJhBiftw, 0, m, &cSlice_NJhBiftw_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_FLANGR::cSlice_NJhBiftw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_gXrt2K9t_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_gXrt2K9t_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_FLANGR::cVar_ZxTH6Pyt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_gXrt2K9t_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cSend_gXrt2K9t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_2HIYiN9z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cMsg_LSGy01Ua_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_TbYIJyE8, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_E7QFQjoH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_R25WMDtl, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_WeGTBPUJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_PTQYycrb_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_Dqwzx8mq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_PTQYycrb_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_pRL567Zm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "speed");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_PTQYycrb_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cMsg_RV229yGR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "intensity");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_PTQYycrb_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_FLANGR::cBinop_ed9gHkvU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_XNCXEE98, 0, m, &cVar_XNCXEE98_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_GUVZlVJ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_HwTPrDxZ, 0, m, &cVar_HwTPrDxZ_sendMessage);
}

void Heavy_WSTD_FLANGR::cBinop_jZcCz4US_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Z7NN4Ukh, 0, m, &cVar_Z7NN4Ukh_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_lMUW4j4C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20.0f, 0, m, &cBinop_b2KXg1rx_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_iTyHNayB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_QfOk2mf9_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_MQAcVnfn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6rvaHEbv_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_H4KD5A0V, 0, m, &cVar_H4KD5A0V_sendMessage);
  cMsg_1VKgQpfU_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_yWisupRi, 0, m, &cVar_yWisupRi_sendMessage);
  cMsg_JiQUqS8d_sendMessage(_c, 0, m);
  cMsg_QQ6ZAyzv_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_YeH0PLL1, 0, m, &cVar_YeH0PLL1_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_iZGPSRnd, 0, m, &cVar_iZGPSRnd_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_MWCMmjE4, 0, m, &cVar_MWCMmjE4_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ZxTH6Pyt, 0, m, &cVar_ZxTH6Pyt_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_E4Uk2yo4, 0, m, &cVar_E4Uk2yo4_sendMessage);
  cMsg_qhKx5iIA_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_ADCgry4n, 0, m, &cVar_ADCgry4n_sendMessage);
  cMsg_EDLkdWcw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_FLANGR::cReceive_2HIYiN9z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_YAoLXO1T_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_xa80hR6C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_FDuflrnr_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_T6wb7rrT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_i1zEDy6b, 0, m, &cVar_i1zEDy6b_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_IRYbXjDZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_ed9gHkvU_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_4tIz208N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_jZcCz4US_sendMessage);
}

void Heavy_WSTD_FLANGR::cReceive_PshM2mDu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_GUVZlVJ0_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_FLANGR::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7;
  hv_bufferi_t Bi0, Bi1;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_line_f(&sLine_R25WMDtl, VOf(Bf0));
    __hv_phasor_k_f(&sPhasor_EZZuEyEr, VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_abs_f(VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf1), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf3), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf2), VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_nf7zY553, VOf(Bf1));
    __hv_var_k_f(VOf(Bf2), 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f, 20.0f);
    __hv_var_k_f(VOf(Bf4), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_mul_f(VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf1), VIf(Bf4), VOf(Bf1));
    __hv_mul_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_neg_f(VIf(Bf1), VOf(Bf3));
    __hv_add_f(VIf(Bf3), VIf(Bf4), VOf(Bf3));
    __hv_varread_f(&sVarf_hXvIjBtS, VOf(Bf2));
    __hv_mul_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_zLRZcbuI, VOf(Bf3));
    __hv_rpole_f(&sRPole_X5mvBjap, VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_v5KyDIX7, VOf(Bf1));
    __hv_mul_f(VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_Uyk69t9V, VOf(Bf4));
    __hv_rpole_f(&sRPole_RZBUGl7o, VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_tabhead_f(&sTabhead_rnJ21DA8, VOf(Bf1));
    __hv_var_k_f_r(VOf(Bf2), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_XkVwlHNR, VOf(Bf1));
    __hv_mul_f(VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_uHMQ7Bnh, VOf(Bf4));
    __hv_min_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_zero_f(VOf(Bf1));
    __hv_max_f(VIf(Bf4), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf2));
    __hv_varread_f(&sVarf_aX55ZHh0, VOf(Bf4));
    __hv_zero_f(VOf(Bf5));
    __hv_lt_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_and_f(VIf(Bf4), VIf(Bf5), VOf(Bf5));
    __hv_add_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_cast_fi(VIf(Bf5), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_NTDDH6VF, VIi(Bi1), VOf(Bf5));
    __hv_tabread_if(&sTabread_PNwHZz5J, VIi(Bi0), VOf(Bf4));
    __hv_sub_f(VIf(Bf5), VIf(Bf4), VOf(Bf5));
    __hv_sub_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_fma_f(VIf(Bf5), VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_TbYIJyE8, VOf(Bf2));
    __hv_mul_f(VIf(Bf4), VIf(Bf2), VOf(Bf5));
    __hv_fma_f(VIf(I0), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_tabhead_f(&sTabhead_NDUXXQMv, VOf(Bf1));
    __hv_var_k_f_r(VOf(Bf6), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_j80Hudrf, VOf(Bf1));
    __hv_mul_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_zdqTmKtj, VOf(Bf3));
    __hv_min_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_zero_f(VOf(Bf1));
    __hv_max_f(VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf6), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf6));
    __hv_varread_f(&sVarf_gnekxkyT, VOf(Bf3));
    __hv_zero_f(VOf(Bf7));
    __hv_lt_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_and_f(VIf(Bf3), VIf(Bf7), VOf(Bf7));
    __hv_add_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_cast_fi(VIf(Bf7), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_DS4vaCZM, VIi(Bi1), VOf(Bf7));
    __hv_tabread_if(&sTabread_YYfSz6CP, VIi(Bi0), VOf(Bf3));
    __hv_sub_f(VIf(Bf7), VIf(Bf3), VOf(Bf7));
    __hv_sub_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_fma_f(VIf(Bf7), VIf(Bf6), VIf(Bf3), VOf(Bf3));
    __hv_mul_f(VIf(Bf2), VIf(Bf3), VOf(Bf2));
    __hv_fma_f(VIf(Bf0), VIf(I1), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_wuT9gamT, VOf(Bf0));
    __hv_fma_f(VIf(Bf0), VIf(Bf3), VIf(I1), VOf(Bf3));
    __hv_tabwrite_f(&sTabwrite_1ixSPqql, VIf(Bf3));
    __hv_fma_f(VIf(Bf4), VIf(Bf0), VIf(I0), VOf(Bf0));
    __hv_tabwrite_f(&sTabwrite_eamEmQVd, VIf(Bf0));
    __hv_add_f(VIf(Bf5), VIf(O0), VOf(O0));
    __hv_add_f(VIf(Bf2), VIf(O1), VOf(O1));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_FLANGR::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_FLANGR::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
