/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_WSTD_FLANGR_HPP_
#define _HEAVY_CONTEXT_WSTD_FLANGR_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvControlCast.h"
#include "HvControlBinop.h"
#include "HvSignalTabwrite.h"
#include "HvSignalRPole.h"
#include "HvSignalVar.h"
#include "HvSignalLine.h"
#include "HvControlVar.h"
#include "HvSignalTabread.h"
#include "HvControlSlice.h"
#include "HvTable.h"
#include "HvMath.h"
#include "HvSignalDel1.h"
#include "HvControlUnop.h"
#include "HvControlDelay.h"
#include "HvControlSystem.h"
#include "HvSignalPhasor.h"

class Heavy_WSTD_FLANGR : public HeavyContext {

 public:
  Heavy_WSTD_FLANGR(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_WSTD_FLANGR();

  const char *getName() override { return "WSTD_FLANGR"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        FEEDBACK = 0x57157946, // Feedback
        INTENSITY = 0x20BB009B, // Intensity
        MIX = 0x97D46AC6, // Mix
        SPEED = 0x9A248230, // Speed
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_HwTPrDxZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_i1zEDy6b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Z7NN4Ukh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_XNCXEE98_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_b2KXg1rx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dgqPQoyS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qhKx5iIA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_M67JPdRz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_E4Uk2yo4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_ljxv6Y1E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iR2ZjAlF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_CPdPVjdG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uPJjFuh5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EDLkdWcw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_uDnM8CHs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ADCgry4n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_7O5qmszt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_d1ZhB3t0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_buEiLFiM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xICAASKZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YAoLXO1T_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_z106eGAS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_GKqS375D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_pkK4AXOD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NNkgkPNg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_BOkGGd5n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gCXbP3zR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Cxcvu6wl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4LqImXNh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IFhlU4ZJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GVpRyKH4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kM7TPWMU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_frrC4wpv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FDuflrnr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zmLApObq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JiQUqS8d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_jflvpGvp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_ktd1YUUy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_qs6htUFW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_0n5r20z7_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_QU9jwFwC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_LlgIMSkF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pCy1dkFL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2VcpjHvm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_P0F5h3UX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cZXzg7kn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xMMSpn4Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_i6NqQLm9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QQ6ZAyzv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_BWgThfTN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_d5x1DpXx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_VQffMIKK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_UAbazszT_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_UpbptDXG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_M7LtidNy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aLoaeQ13_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rRwF8VO7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6DfE5Xzh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MPlEYjcA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ua7bQKLw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kvSJC1S9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_H4KD5A0V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6rvaHEbv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_n9sLrFLw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HWvOm9Ny_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TdyozPUV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Aykgt5no_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_c2VmB4pJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8kHVMDen_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wstOkoPJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_yWisupRi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1VKgQpfU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_nJdkwEAv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hI6pTwi1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RSFX4cBx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_g5XVORdI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4K0wdpK6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Hl4sFdD5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_wYSmyn3K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rUmrdgS4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_p1YbjCbt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_v5MbXFPF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JqNwI0t1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gj3wttXq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Kh6Mt6Bq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_F2Bq0ygB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_opCCArKP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2p80xbFM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_cDZUsf6S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QfOk2mf9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tT2aBm9c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_PTQYycrb_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_CxtlHDBG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_YeH0PLL1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_GeJv0Zbs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_0wyqN356_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_C1keHI8g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_iZGPSRnd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_rb75OlzK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_1rpLPxbT_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_gfrUcuP0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_MWCMmjE4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_covEy1Yb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_Bwv3DNnF_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_NJhBiftw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ZxTH6Pyt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_gXrt2K9t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LSGy01Ua_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_E7QFQjoH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WeGTBPUJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Dqwzx8mq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pRL567Zm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_RV229yGR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ed9gHkvU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GUVZlVJ0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jZcCz4US_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_lMUW4j4C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_iTyHNayB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_MQAcVnfn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_2HIYiN9z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_xa80hR6C_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_T6wb7rrT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_IRYbXjDZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_4tIz208N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_PshM2mDu_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalLine sLine_R25WMDtl;
  SignalPhasor sPhasor_EZZuEyEr;
  SignalLine sLine_nf7zY553;
  SignalRPole sRPole_X5mvBjap;
  SignalRPole sRPole_RZBUGl7o;
  SignalTabhead sTabhead_rnJ21DA8;
  SignalTabread sTabread_NTDDH6VF;
  SignalTabread sTabread_PNwHZz5J;
  SignalLine sLine_TbYIJyE8;
  SignalTabhead sTabhead_NDUXXQMv;
  SignalTabread sTabread_DS4vaCZM;
  SignalTabread sTabread_YYfSz6CP;
  SignalLine sLine_wuT9gamT;
  SignalTabwrite sTabwrite_1ixSPqql;
  SignalTabwrite sTabwrite_eamEmQVd;
  ControlVar cVar_HwTPrDxZ;
  ControlVar cVar_i1zEDy6b;
  ControlVar cVar_Z7NN4Ukh;
  ControlVar cVar_XNCXEE98;
  ControlBinop cBinop_b2KXg1rx;
  ControlBinop cBinop_dgqPQoyS;
  ControlVar cVar_E4Uk2yo4;
  ControlBinop cBinop_iR2ZjAlF;
  ControlBinop cBinop_uPJjFuh5;
  SignalVarf sVarf_aX55ZHh0;
  SignalVarf sVarf_XkVwlHNR;
  SignalVarf sVarf_uHMQ7Bnh;
  ControlVar cVar_ADCgry4n;
  ControlBinop cBinop_d1ZhB3t0;
  ControlBinop cBinop_xICAASKZ;
  SignalVarf sVarf_gnekxkyT;
  SignalVarf sVarf_j80Hudrf;
  SignalVarf sVarf_zdqTmKtj;
  ControlBinop cBinop_YAoLXO1T;
  ControlBinop cBinop_z106eGAS;
  ControlBinop cBinop_NNkgkPNg;
  ControlBinop cBinop_BOkGGd5n;
  ControlBinop cBinop_4LqImXNh;
  ControlBinop cBinop_GVpRyKH4;
  ControlBinop cBinop_kM7TPWMU;
  ControlBinop cBinop_frrC4wpv;
  ControlBinop cBinop_FDuflrnr;
  ControlBinop cBinop_zmLApObq;
  ControlDelay cDelay_ktd1YUUy;
  ControlDelay cDelay_qs6htUFW;
  ControlBinop cBinop_QU9jwFwC;
  HvTable hTable_LlgIMSkF;
  ControlBinop cBinop_2VcpjHvm;
  ControlDelay cDelay_d5x1DpXx;
  ControlDelay cDelay_VQffMIKK;
  ControlBinop cBinop_UpbptDXG;
  HvTable hTable_M7LtidNy;
  ControlBinop cBinop_rRwF8VO7;
  ControlVar cVar_H4KD5A0V;
  ControlBinop cBinop_HWvOm9Ny;
  ControlBinop cBinop_TdyozPUV;
  SignalVarf sVarf_zLRZcbuI;
  ControlBinop cBinop_c2VmB4pJ;
  ControlBinop cBinop_8kHVMDen;
  ControlBinop cBinop_wstOkoPJ;
  SignalVarf sVarf_hXvIjBtS;
  ControlVar cVar_yWisupRi;
  ControlBinop cBinop_hI6pTwi1;
  ControlBinop cBinop_RSFX4cBx;
  SignalVarf sVarf_Uyk69t9V;
  ControlBinop cBinop_4K0wdpK6;
  ControlBinop cBinop_Hl4sFdD5;
  ControlBinop cBinop_wYSmyn3K;
  SignalVarf sVarf_v5KyDIX7;
  ControlBinop cBinop_gj3wttXq;
  ControlBinop cBinop_Kh6Mt6Bq;
  ControlBinop cBinop_F2Bq0ygB;
  ControlBinop cBinop_opCCArKP;
  ControlBinop cBinop_2p80xbFM;
  ControlBinop cBinop_QfOk2mf9;
  ControlBinop cBinop_tT2aBm9c;
  ControlSlice cSlice_CxtlHDBG;
  ControlVar cVar_YeH0PLL1;
  ControlSlice cSlice_C1keHI8g;
  ControlVar cVar_iZGPSRnd;
  ControlSlice cSlice_gfrUcuP0;
  ControlVar cVar_MWCMmjE4;
  ControlSlice cSlice_NJhBiftw;
  ControlVar cVar_ZxTH6Pyt;
  ControlBinop cBinop_ed9gHkvU;
  ControlBinop cBinop_GUVZlVJ0;
  ControlBinop cBinop_jZcCz4US;
};

#endif // _HEAVY_CONTEXT_WSTD_FLANGR_HPP_
